@@ -42,6 +42,7 @@ Messaging
    <ja>暗号化したつぶやきを経由した、2PC間のチャット</ja>
    <kk>voice chat between two pc's via encrypted mumble</kk>
    <ko>voice chat between two pc's via encrypted mumble</ko>
+   <ku>voice chat between two pc's via encrypted mumble</ku>
    <lt>voice chat between two pc's via encrypted mumble</lt>
    <mk>voice chat between two pc's via encrypted mumble</mk>
    <mr>voice chat between two pc's via encrypted mumble</mr>
@@ -49,6 +50,7 @@ Messaging
    <nb>nett-telefoni mellom to pc-er via kryptert mumble</nb>
    <nl_BE>voice chat between two pc's via encrypted mumble</nl_BE>
    <nl>voice chat tussen twee PCs via beveiligde mumble</nl>
+   <or>voice chat between two pc's via encrypted mumble</or>
    <pl>czat głosowy pomiędzy dwoma komputerami szyfrowany przez mumble</pl>
    <pt_BR>Bate-papo de voz entre dois computadores via mumble criptografado/encriptado</pt_BR>
    <pt>Chat de voz entre dois computadores via mumble encriptado</pt>
@@ -56,6 +58,7 @@ Messaging
    <ru>Голосовой чат между двумя PC через шифрованный канал</ru>
    <sk>voice chat between two pc's via encrypted mumble</sk>
    <sl>Glasovni pogovor med dvema računalnikoma preko šifriranega Mumble</sl>
+   <so>voice chat between two pc's via encrypted mumble</so>
    <sq>Fjalosje me zë mes dy kompjuterash, përmes Mumble-i të fshehtëzuar</sq>
    <sr>voice chat between two pc's via encrypted mumble</sr>
    <sv>röstchatt mellan två pc's via encrypted mumble</sv>
