@@ -42,6 +42,7 @@ Albanian_Firefox
    <ja>アルバニア語版 Firefox</ja>
    <kk>Albanian localisation of Firefox</kk>
    <ko>Albanian localisation of Firefox</ko>
+   <ku>Albanian localisation of Firefox</ku>
    <lt>Albanian localisation of Firefox</lt>
    <mk>Albanian localisation of Firefox</mk>
    <mr>Albanian localisation of Firefox</mr>
@@ -49,6 +50,7 @@ Albanian_Firefox
    <nb>Albansk lokaltilpassing av Firefox</nb>
    <nl_BE>Albanian localisation of Firefox</nl_BE>
    <nl>Albanese lokalisatie van Firefox</nl>
+   <or>Albanian localisation of Firefox</or>
    <pl>Albańska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Albanês Localização para o Firefox</pt_BR>
    <pt>Albanês Localização para Firefox</pt>
@@ -56,6 +58,7 @@ Albanian_Firefox
    <ru>Албанская локализация Firefox</ru>
    <sk>Albanian lokalizácia pre Firefox</sk>
    <sl>Albanske krajevne nastavitve za Firefox</sl>
+   <so>Albanian localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në shqip</sq>
    <sr>Albanian localisation of Firefox</sr>
    <sv>Albansk lokalisering av Firefox</sv>
