@@ -42,13 +42,15 @@ Breton
    <ja>Hunspell 用ブルトン語辞書</ja>
    <kk>Breton dictionary for hunspell</kk>
    <ko>Breton dictionary for hunspell</ko>
+   <ku>Breton dictionary for hunspell</ku>
    <lt>Breton dictionary for hunspell</lt>
    <mk>Breton dictionary for hunspell</mk>
    <mr>Breton dictionary for hunspell</mr>
    <nb_NO>Breton dictionary for hunspell</nb_NO>
    <nb>Bretonsk ordliste for hunspell</nb>
    <nl_BE>Breton dictionary for hunspell</nl_BE>
-   <nl>Breton dictionary for hunspell</nl>
+   <nl>Bretons woordenboek voor hunspell</nl>
+   <or>Breton dictionary for hunspell</or>
    <pl>Breton dictionary for hunspell</pl>
    <pt_BR>Dicionário Bretão para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Bretão para hunspell</pt>
@@ -56,6 +58,7 @@ Breton
    <ru>Breton dictionary for hunspell</ru>
    <sk>Breton dictionary for hunspell</sk>
    <sl>Bretonski slovar za hunspell</sl>
+   <so>Breton dictionary for hunspell</so>
    <sq>Fjalor bretonisht për hunspell</sq>
    <sr>Breton dictionary for hunspell</sr>
    <sv>Bretonsk ordbok för hunspell</sv>
