@@ -42,6 +42,7 @@ Chinese_CN_LO_main
    <ja>LibreOffice の簡体中国語版</ja>
    <kk>Chinese_simplified localisation of LibreOffice</kk>
    <ko>Chinese_simplified localisation of LibreOffice</ko>
+   <ku>Chinese_simplified localisation of LibreOffice</ku>
    <lt>Chinese_simplified localisation of LibreOffice</lt>
    <mk>Chinese_simplified localisation of LibreOffice</mk>
    <mr>Chinese_simplified localisation of LibreOffice</mr>
@@ -49,6 +50,7 @@ Chinese_CN_LO_main
    <nb>Kinesisk (forenklet) lokaltilpassing av LibreOffice</nb>
    <nl_BE>Chinese_simplified localisation of LibreOffice</nl_BE>
    <nl>Vereenvoudigd Chinese lokalisatie van LibreOffice</nl>
+   <or>Chinese_simplified localisation of LibreOffice</or>
    <pl>Chiński uproszczony lokalizacja LibreOffice</pl>
    <pt_BR>Chinês Simplificado Localização para o LibreOffice</pt_BR>
    <pt>Chinês_simplificado Localização para LibreOffice</pt>
@@ -56,6 +58,7 @@ Chinese_CN_LO_main
    <ru>Chinese_simplified localisation of LibreOffice</ru>
    <sk>Chinese_simplified localisation of LibreOffice</sk>
    <sl>Kitajske (poenostavljeno) krajevne nastavitve za LibreOffice</sl>
+   <so>Chinese_simplified localisation of LibreOffice</so>
    <sq>Përkthimi i LibreOffice-it në kinezçe të thjeshtuar</sq>
    <sr>Chinese_simplified localisation of LibreOffice</sr>
    <sv>Kinesisk_förenklad lokalisering av LibreOffice</sv>
