@@ -42,6 +42,7 @@ Chinese_Font
    <ja>中国語用のフォントパッケージ</ja>
    <kk>Chinese fonts packages</kk>
    <ko>Chinese fonts packages</ko>
+   <ku>Chinese fonts packages</ku>
    <lt>Kinų šriftų paketai</lt>
    <mk>Chinese fonts packages</mk>
    <mr>Chinese fonts packages</mr>
@@ -49,6 +50,7 @@ Chinese_Font
    <nb>Pakke med kinesiske skrifttyper</nb>
    <nl_BE>Chinese fonts packages</nl_BE>
    <nl>Chinese font pakketten</nl>
+   <or>Chinese fonts packages</or>
    <pl>pakiety z chińskimi fontami (czcionkami)</pl>
    <pt_BR>Pacotes de Fontes Chinês</pt_BR>
    <pt>Chinês Pacotes de fontes</pt>
@@ -56,6 +58,7 @@ Chinese_Font
    <ru>Пакеты китайских шрифтов</ru>
    <sk>Chinese fonts packages</sk>
    <sl>Kitajski paketi s pisavami</sl>
+   <so>Chinese fonts packages</so>
    <sq>Paketash shkronjash për kinezçen</sq>
    <sr>Chinese fonts packages</sr>
    <sv>Kinesiska typsnitts-paket</sv>
