@@ -42,13 +42,15 @@ Cinnamon-Standard
    <ja>Cinnamonデスクトップの標準インストール</ja>
    <kk>Cinnamon desktop - standard install</kk>
    <ko>Cinnamon desktop - standard install</ko>
+   <ku>Cinnamon desktop - standard install</ku>
    <lt>Cinnamon desktop - standard install</lt>
    <mk>Cinnamon desktop - standard install</mk>
    <mr>Cinnamon desktop - standard install</mr>
    <nb_NO>Cinnamon desktop - standard install</nb_NO>
    <nb>Skrivebordet Cinnamon – standard installasjon</nb>
    <nl_BE>Cinnamon desktop - standard install</nl_BE>
-   <nl>Cinnamon desktop - standard install</nl>
+   <nl>Cinnamon desktop - standaard installatie</nl>
+   <or>Cinnamon desktop - standard install</or>
    <pl>Cinnamon desktop - standard install</pl>
    <pt_BR>Área de Trabalho Cinnamon/Canela - instalação padrão</pt_BR>
    <pt>Ambiente de trabalho Cinnamon - instalação padrão</pt>
@@ -56,6 +58,7 @@ Cinnamon-Standard
    <ru>Cinnamon desktop - standard install</ru>
    <sk>Cinnamon desktop - standard install</sk>
    <sl>Cinnamon namizje - standardna namestitev</sl>
+   <so>Cinnamon desktop - standard install</so>
    <sq>Desktopi Cinnamon - instalim standard</sq>
    <sr>Cinnamon desktop - standard install</sr>
    <sv>Cinnamon skrivbordsmiljö - standard installation</sv>
