@@ -42,6 +42,7 @@ Kernel-Debian_32bit_PAE
    <ja>Fallback Debian 4.19 32bit PAE linux kernel</ja>
    <kk>Fallback Debian 4.19 32bit PAE linux kernel</kk>
    <ko>Fallback Debian 4.19 32bit PAE linux kernel</ko>
+   <ku>Fallback Debian 4.19 32bit PAE linux kernel</ku>
    <lt>Fallback Debian 4.19 32bit PAE linux kernel</lt>
    <mk>Fallback Debian 4.19 32bit PAE linux kernel</mk>
    <mr>Fallback Debian 4.19 32bit PAE linux kernel</mr>
@@ -49,13 +50,15 @@ Kernel-Debian_32bit_PAE
    <nb>Siste utvei – Debian 4.19 32-biters PAE Linux-kjerne</nb>
    <nl_BE>Fallback Debian 4.19 32bit PAE linux kernel</nl_BE>
    <nl>Fallback Debian 4.19 32bit PAE linux kernel</nl>
+   <or>Fallback Debian 4.19 32bit PAE linux kernel</or>
    <pl>Fallback Debian 4.19 32bit PAE linux kernel</pl>
    <pt_BR>Fallback do Debian 4.19 de 32 bits PAE linux kernel</pt_BR>
    <pt>Núcleo (Kernel) linux Debian 4.19 32bit PAE de reserva</pt>
    <ro>Fallback Debian 4.19 32bit PAE linux kernel</ro>
    <ru>Fallback Debian 4.19 32bit PAE linux kernel</ru>
    <sk>Fallback Debian 4.19 32bit PAE linux kernel</sk>
-   <sl>Fallback Debian 4.19 32bit PAE linux kernel</sl>
+   <sl>Starejše Debian 4.19 32bit PAE linux jedro</sl>
+   <so>Fallback Debian 4.19 32bit PAE linux kernel</so>
    <sq>Fallback Debian 4.19 32bit PAE linux kernel</sq>
    <sr>Fallback Debian 4.19 32bit PAE linux kernel</sr>
    <sv>Fallback Debian 4.19 32bit PAE linux-kärna</sv>
@@ -79,8 +82,8 @@ Kernel-Debian_32bit_PAE
 </preinstall>
 
 <install_package_names>
-linux-image-4.19.0-17-686-pae
-linux-headers-4.19.0-17-686-pae
+linux-image-5.10.0-9-686-pae
+linux-headers-5.10.0-9-686-pae
 </install_package_names>
 
 <postinstall>
@@ -88,8 +91,8 @@ linux-headers-4.19.0-17-686-pae
 </postinstall>
 
 <uninstall_package_names>
-linux-image-4.19.0-17-686-pae
-linux-headers-4.19.0-17-686-pae
+linux-image-5.10.0-9-686-pae
+linux-headers-5.10.0-9-686-pae
 </uninstall_package_names>
 
 </app>
