@@ -42,13 +42,15 @@ English (South Africa)
    <ja>Hunspell 用英語（南アフリカ）辞書</ja>
    <kk>English (South Africa) dictionary for hunspell</kk>
    <ko>English (South Africa) dictionary for hunspell</ko>
+   <ku>English (South Africa) dictionary for hunspell</ku>
    <lt>English (South Africa) dictionary for hunspell</lt>
    <mk>English (South Africa) dictionary for hunspell</mk>
    <mr>English (South Africa) dictionary for hunspell</mr>
    <nb_NO>English (South Africa) dictionary for hunspell</nb_NO>
    <nb>Engelsk (sør-afrikansk) ordliste for hunspell</nb>
    <nl_BE>English (South Africa) dictionary for hunspell</nl_BE>
-   <nl>English (South Africa) dictionary for hunspell</nl>
+   <nl>Engels (Zuid-Afrika) woordenboek voor hunspell</nl>
+   <or>English (South Africa) dictionary for hunspell</or>
    <pl>English (South Africa) dictionary for hunspell</pl>
    <pt_BR>Dicionário Inglês (África do Sul) para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Inglês (África do Sul) para hunspell</pt>
@@ -56,6 +58,7 @@ English (South Africa)
    <ru>English (South Africa) dictionary for hunspell</ru>
    <sk>English (South Africa) dictionary for hunspell</sk>
    <sl>Angleški (južnoafriška) slovar za hunspell</sl>
+   <so>English (South Africa) dictionary for hunspell</so>
    <sq>Fjalor anglisht (Afrikë e Jugut) për hunspell</sq>
    <sr>English (South Africa) dictionary for hunspell</sr>
    <sv>Engelsk (Sydafrika) ordbok för hunspell</sv>
