@@ -42,13 +42,15 @@ Galician_Thunderbird
    <ja>ガリシア語版 Thunderbird</ja>
    <kk>Galician localisation of Thunderbird</kk>
    <ko>Galician localisation of Thunderbird</ko>
+   <ku>Galician localisation of Thunderbird</ku>
    <lt>Galician localisation of Thunderbird</lt>
    <mk>Galician localisation of Thunderbird</mk>
    <mr>Galician localisation of Thunderbird</mr>
    <nb_NO>Galician localisation of Thunderbird</nb_NO>
    <nb>Galisisk lokaltilpassing av Thunderbird</nb>
    <nl_BE>Galician localisation of Thunderbird</nl_BE>
-   <nl>Galician localisation of Thunderbird</nl>
+   <nl>Galicische lokalisatie van Thunderbird</nl>
+   <or>Galician localisation of Thunderbird</or>
    <pl>Galician localisation of Thunderbird</pl>
    <pt_BR>Galego Localização para o Thunderbird</pt_BR>
    <pt>Galego Localização para Thunderbird</pt>
@@ -56,6 +58,7 @@ Galician_Thunderbird
    <ru>Galician localisation of Thunderbird</ru>
    <sk>Galician localisation of Thunderbird</sk>
    <sl>Galicijske krajevne of Thunderbird</sl>
+   <so>Galician localisation of Thunderbird</so>
    <sq>Fjalor galicisht për hunspell</sq>
    <sr>Galician localisation of Thunderbird</sr>
    <sv>Galicisk lokalisering av Thunderbird</sv>
