@@ -42,6 +42,7 @@ Hungarian_Default_Firefox_esr
    <ja>ブルガリア語版 Firefox ESR</ja>
    <kk>Hungarian localisation of Firefox ESR</kk>
    <ko>Hungarian localisation of Firefox ESR</ko>
+   <ku>Hungarian localisation of Firefox ESR</ku>
    <lt>Hungarian localisation of Firefox ESR</lt>
    <mk>Hungarian localisation of Firefox ESR</mk>
    <mr>Hungarian localisation of Firefox ESR</mr>
@@ -49,6 +50,7 @@ Hungarian_Default_Firefox_esr
    <nb>Ungarsk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Hungarian localisation of Firefox ESR</nl_BE>
    <nl>Hungarian localisation of Firefox ESR</nl>
+   <or>Hungarian localisation of Firefox ESR</or>
    <pl>Hungarian localisation of Firefox ESR</pl>
    <pt_BR>Húngaro Localização para o Firefox ESR</pt_BR>
    <pt>Húngaro Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Hungarian_Default_Firefox_esr
    <ru>Hungarian localisation of Firefox ESR</ru>
    <sk>Hungarian localisation of Firefox ESR</sk>
    <sl>Madžarske krajevne nastavitve za Firefox ESR</sl>
+   <so>Hungarian localisation of Firefox ESR</so>
    <sq>HPLIP dhe ekstra shtypjeje</sq>
    <sr>Hungarian localisation of Firefox ESR</sr>
    <sv>Ungersk lokalisering av Firefox ESR</sv>
