@@ -42,6 +42,7 @@ Korean_LO_main
    <ja>LibreOffice の韓国（朝鮮）語版</ja>
    <kk>Korean localisation of LibreOffice</kk>
    <ko>Korean localisation of LibreOffice</ko>
+   <ku>Korean localisation of LibreOffice</ku>
    <lt>Korean localisation of LibreOffice</lt>
    <mk>Korean localisation of LibreOffice</mk>
    <mr>Korean localisation of LibreOffice</mr>
@@ -49,6 +50,7 @@ Korean_LO_main
    <nb>Koreansk lokaltilpassing av LibreOffice</nb>
    <nl_BE>Korean localisation of LibreOffice</nl_BE>
    <nl>Koreaanse lokalisatie van LibreOffice</nl>
+   <or>Korean localisation of LibreOffice</or>
    <pl>Koreańska lokalizacja LibreOffice</pl>
    <pt_BR>Coreano Localização para o LibreOffice</pt_BR>
    <pt>Coreano Localização para LibreOffice</pt>
@@ -56,6 +58,7 @@ Korean_LO_main
    <ru>Korean localisation of LibreOffice</ru>
    <sk>Korean localisation of LibreOffice</sk>
    <sl>Korejske krajevne nastavitve za LibreOffice</sl>
+   <so>Korean localisation of LibreOffice</so>
    <sq>Përkthim i LibreOffice-it në koreançe</sq>
    <sr>Korean localisation of LibreOffice</sr>
    <sv>Koreansk lokalisering av LibreOffice</sv>
