@@ -42,6 +42,7 @@ Lithuanian_LO_full
    <ja>LibreOffice用のリトアニア語メタパッケージ</ja>
    <kk>Lithuanian Language Meta-Package for LibreOffice</kk>
    <ko>Lithuanian Language Meta-Package for LibreOffice</ko>
+   <ku>Lithuanian Language Meta-Package for LibreOffice</ku>
    <lt>Lithuanian Language Meta-Package for LibreOffice</lt>
    <mk>Lithuanian Language Meta-Package for LibreOffice</mk>
    <mr>Lithuanian Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Lithuanian_LO_full
    <nb>Litauisk språkpakke for LibreOffice</nb>
    <nl_BE>Lithuanian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Litouws Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Lithuanian Language Meta-Package for LibreOffice</or>
    <pl>Litewski meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Lituano Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Lituano Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Lithuanian_LO_full
    <ru>Lithuanian Language Meta-Package for LibreOffice</ru>
    <sk>Lithuanian Language Meta-Package for LibreOffice</sk>
    <sl>Litvanski jezikovni meta-paket za LibreOffice</sl>
+   <so>Lithuanian Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në lituanisht</sq>
    <sr>Lithuanian Language Meta-Package for LibreOffice</sr>
    <sv>Litauiskt Språk Meta-Paket för LibreOffice</sv>
