@@ -42,6 +42,7 @@ Marathi_LO_main
    <ja>LibreOffice用のマラーティー語メタパッケージ</ja>
    <kk>Marathi Language Meta-Package for LibreOffice</kk>
    <ko>Marathi Language Meta-Package for LibreOffice</ko>
+   <ku>Marathi Language Meta-Package for LibreOffice</ku>
    <lt>Marathi Language Meta-Package for LibreOffice</lt>
    <mk>Marathi Language Meta-Package for LibreOffice</mk>
    <mr>Marathi Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Marathi_LO_main
    <nb>Marathi språkpakke for LibreOffice</nb>
    <nl_BE>Marathi Language Meta-Package for LibreOffice</nl_BE>
    <nl>Marathi Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Marathi Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Marathi dla LibreOffice</pl>
    <pt_BR>Marata Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Marata Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Marathi_LO_main
    <ru>Marathi Language Meta-Package for LibreOffice</ru>
    <sk>Marathi Language Meta-Package for LibreOffice</sk>
    <sl>Maratski jezikovni meta-paket za LibreOffice</sl>
+   <so>Marathi Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në marati</sq>
    <sr>Marathi Language Meta-Package for LibreOffice</sr>
    <sv>Marathi Språk Meta-Paket för LibreOffice</sv>
