@@ -42,6 +42,7 @@ Occitan_LO_full
    <ja>LibreOffice用のオック語メタパッケージ</ja>
    <kk>Occitan Language Meta-Package for LibreOffice</kk>
    <ko>Occitan Language Meta-Package for LibreOffice</ko>
+   <ku>Occitan Language Meta-Package for LibreOffice</ku>
    <lt>Occitan Language Meta-Package for LibreOffice</lt>
    <mk>Occitan Language Meta-Package for LibreOffice</mk>
    <mr>Occitan Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Occitan_LO_full
    <nb>Oksitansk språkpakke for LibreOffice</nb>
    <nl_BE>Occitan Language Meta-Package for LibreOffice</nl_BE>
    <nl>Occitan Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Occitan Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Occitan dla LibreOffice</pl>
    <pt_BR>Occitana Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Occitano Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Occitan_LO_full
    <ru>Occitan Language Meta-Package for LibreOffice</ru>
    <sk>Occitan Language Meta-Package for LibreOffice</sk>
    <sl>Okitanski jezikovni meta-paket za LibreOffice</sl>
+   <so>Occitan Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në oçitanisht</sq>
    <sr>Occitan Language Meta-Package for LibreOffice</sr>
    <sv>Occitan Språk Meta-Paket för LibreOffice</sv>
