@@ -42,6 +42,7 @@ Romansh_Default_Firefox_esr
    <ja>Romansh localisation of Firefox ESR</ja>
    <kk>Romansh localisation of Firefox ESR</kk>
    <ko>Romansh localisation of Firefox ESR</ko>
+   <ku>Romansh localisation of Firefox ESR</ku>
    <lt>Romansh localisation of Firefox ESR</lt>
    <mk>Romansh localisation of Firefox ESR</mk>
    <mr>Romansh localisation of Firefox ESR</mr>
@@ -49,13 +50,15 @@ Romansh_Default_Firefox_esr
    <nb>Romansh lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Romansh localisation of Firefox ESR</nl_BE>
    <nl>Romansh localisation of Firefox ESR</nl>
+   <or>Romansh localisation of Firefox ESR</or>
    <pl>Romansh localisation of Firefox ESR</pl>
    <pt_BR>Romanche Localização para o Firefox ESR</pt_BR>
    <pt>Romanche Localização para Firefox ESR</pt>
    <ro>Romansh localisation of Firefox ESR</ro>
    <ru>Romansh localisation of Firefox ESR</ru>
    <sk>Romansh localisation of Firefox ESR</sk>
-   <sl>Romansh localisation of Firefox ESR</sl>
+   <sl>Retoromanske krajevne nastavitve za Firefox ESR</sl>
+   <so>Romansh localisation of Firefox ESR</so>
    <sq>Romansh localisation of Firefox ESR</sq>
    <sr>Romansh localisation of Firefox ESR</sr>
    <sv>Romansk lokalisering av Firefox ESR</sv>
