@@ -42,6 +42,7 @@ Russian_Thunderbird
    <ja>Thunderbird のロシア語版</ja>
    <kk>Russian localisation of Thunderbird</kk>
    <ko>Russian localisation of Thunderbird</ko>
+   <ku>Russian localisation of Thunderbird</ku>
    <lt>Russian localisation of Thunderbird</lt>
    <mk>Russian localisation of Thunderbird</mk>
    <mr>Russian localisation of Thunderbird</mr>
@@ -49,6 +50,7 @@ Russian_Thunderbird
    <nb>Russisk lokaltilpassing av Thunderbird</nb>
    <nl_BE>Russian localisation of Thunderbird</nl_BE>
    <nl>Russische lokalisatie van Thunderbird</nl>
+   <or>Russian localisation of Thunderbird</or>
    <pl>Rosyjska lokalizacja Thunderbirda</pl>
    <pt_BR>Russo Localização para o Thunderbird</pt_BR>
    <pt>Russo Localização para Thunderbird</pt>
@@ -56,6 +58,7 @@ Russian_Thunderbird
    <ru>Русский перевод для Thunderbird</ru>
    <sk>Russian localisation of Thunderbird</sk>
    <sl>Ruske krajevne nastavitve za Thunderbird</sl>
+   <so>Russian localisation of Thunderbird</so>
    <sq>Përkthimi në rusisht i Thunderbird-it</sq>
    <sr>Russian localisation of Thunderbird</sr>
    <sv>Rysk  lokalisering av Thunderbird</sv>
