@@ -42,6 +42,7 @@ Spanish
    <ja>Hunspell 用スペイン語辞書</ja>
    <kk>Spanish dictionary for hunspell</kk>
    <ko>Spanish dictionary for hunspell</ko>
+   <ku>Spanish dictionary for hunspell</ku>
    <lt>Spanish dictionary for hunspell</lt>
    <mk>Spanish dictionary for hunspell</mk>
    <mr>Spanish dictionary for hunspell</mr>
@@ -49,6 +50,7 @@ Spanish
    <nb>Spansk ordliste for hunspell</nb>
    <nl_BE>Spanish dictionary for hunspell</nl_BE>
    <nl>Spanish dictionary for hunspell</nl>
+   <or>Spanish dictionary for hunspell</or>
    <pl>Spanish dictionary for hunspell</pl>
    <pt_BR>Dicionário Espanhol para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Espanhol para hunspell</pt>
@@ -56,6 +58,7 @@ Spanish
    <ru>Spanish dictionary for hunspell</ru>
    <sk>Spanish dictionary for hunspell</sk>
    <sl>Španski slovar za hunspell</sl>
+   <so>Spanish dictionary for hunspell</so>
    <sq>Fjalor spanjisht për hunspell</sq>
    <sr>Spanish dictionary for hunspell</sr>
    <sv>Spansk ordbok för hunspell</sv>
