@@ -42,6 +42,7 @@ Ukrainian
    <ja>Hunspell 用ウクライナ語辞書</ja>
    <kk>Ukrainian dictionary for hunspell</kk>
    <ko>Ukrainian dictionary for hunspell</ko>
+   <ku>Ukrainian dictionary for hunspell</ku>
    <lt>Ukrainian dictionary for hunspell</lt>
    <mk>Ukrainian dictionary for hunspell</mk>
    <mr>Ukrainian dictionary for hunspell</mr>
@@ -49,6 +50,7 @@ Ukrainian
    <nb>Ukrainsk ordliste for hunspell</nb>
    <nl_BE>Ukrainian dictionary for hunspell</nl_BE>
    <nl>Ukrainian dictionary for hunspell</nl>
+   <or>Ukrainian dictionary for hunspell</or>
    <pl>Ukrainian dictionary for hunspell</pl>
    <pt_BR>Dicionário Ucraniano para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Ucraniano para hunspell</pt>
@@ -56,6 +58,7 @@ Ukrainian
    <ru>Ukrainian dictionary for hunspell</ru>
    <sk>Ukrainian dictionary for hunspell</sk>
    <sl>Ukrajinski slovar za hunspell</sl>
+   <so>Ukrainian dictionary for hunspell</so>
    <sq>Fjalor ukrainisht për hunspell</sq>
    <sr>Ukrainian dictionary for hunspell</sr>
    <sv>Ukrainsk ordbok för hunspell</sv>
