@@ -42,6 +42,7 @@ Ukrainian_LO_main
    <ja>LibreOffice のウクライナ語版</ja>
    <kk>Ukrainian localisation of LibreOffice</kk>
    <ko>Ukrainian localisation of LibreOffice</ko>
+   <ku>Ukrainian localisation of LibreOffice</ku>
    <lt>Ukrainian localisation of LibreOffice</lt>
    <mk>Ukrainian localisation of LibreOffice</mk>
    <mr>Ukrainian localisation of LibreOffice</mr>
@@ -49,6 +50,7 @@ Ukrainian_LO_main
    <nb>Ukrainsk lokaltilpassing av LibreOffice</nb>
    <nl_BE>Ukrainian localisation of LibreOffice</nl_BE>
    <nl>Oekraïense lokalisatie van LibreOffice</nl>
+   <or>Ukrainian localisation of LibreOffice</or>
    <pl>Ukraińska lokalizacja LibreOffice</pl>
    <pt_BR>Ucraniano Localização para o LibreOffice</pt_BR>
    <pt>Ucraniano Localização para LibreOffice</pt>
@@ -56,6 +58,7 @@ Ukrainian_LO_main
    <ru>Ukrainian localisation of LibreOffice</ru>
    <sk>Ukrainian localisation of LibreOffice</sk>
    <sl>Ukrajinske krajevne nastavitve za LibreOffice</sl>
+   <so>Ukrainian localisation of LibreOffice</so>
    <sq>Përkthim i LibreOffice-it në ukrainisht</sq>
    <sr>Ukrainian localisation of LibreOffice</sr>
    <sv>Ukrainsk lokalisering av LibreOffice</sv>
