@@ -42,6 +42,7 @@ Blueman
    <ja>GTK+ bluetooth 管理ユーティリティ</ja>
    <kk>a GTK+ bluetooth management utility</kk>
    <ko>a GTK+ bluetooth management utility</ko>
+   <ku>a GTK+ bluetooth management utility</ku>
    <lt>a GTK+ bluetooth management utility</lt>
    <mk>a GTK+ bluetooth management utility</mk>
    <mr>a GTK+ bluetooth management utility</mr>
@@ -49,6 +50,7 @@ Blueman
    <nb>behandling av blåtannstilkoblinger (GTK+)</nb>
    <nl_BE>a GTK+ bluetooth management utility</nl_BE>
    <nl>een GTK+ bluetooth beheer utility</nl>
+   <or>a GTK+ bluetooth management utility</or>
    <pl>narzędzie GTK+ do zarządzania bluetooth</pl>
    <pt_BR>Utilitário de gerenciamento de bluetooth para uso em GTK+</pt_BR>
    <pt>Utilitário de gestão de bluetooth para uso em GTK+</pt>
@@ -56,6 +58,7 @@ Blueman
    <ru>GTK+ утилита управления bluetooth</ru>
    <sk>a GTK+ bluetooth management utility</sk>
    <sl>GTK+ orodje za upravljanje bluetooth povezav</sl>
+   <so>a GTK+ bluetooth management utility</so>
    <sq>Një mjet GTK+ administrimi bluetooth-i</sq>
    <sr>a GTK+ bluetooth management utility</sr>
    <sv>ett GTK+ bluetooth hanteringsverktyg</sv>
