@@ -42,6 +42,7 @@ Papirus-Mini antiX
    <ja>AntiX Linux用Papirusアイコンの基本バージョン</ja>
    <kk>Basic set of Papirus icons for antiX Linux</kk>
    <ko>Basic set of Papirus icons for antiX Linux</ko>
+   <ku>Basic set of Papirus icons for antiX Linux</ku>
    <lt>Basic set of Papirus icons for antiX Linux</lt>
    <mk>Basic set of Papirus icons for antiX Linux</mk>
    <mr>Basic set of Papirus icons for antiX Linux</mr>
@@ -49,6 +50,7 @@ Papirus-Mini antiX
    <nb>Grunnleggende sett med Papirus-ikoner for antiX Linux</nb>
    <nl_BE>Basic set of Papirus icons for antiX Linux</nl_BE>
    <nl>Basic set of Papirus icons for antiX Linux</nl>
+   <or>Basic set of Papirus icons for antiX Linux</or>
    <pl>Basic set of Papirus icons for antiX Linux</pl>
    <pt_BR>Conjunto básico de ícones do Papirus para o antiX Linux</pt_BR>
    <pt>Conjunto básico de ícones Papirus para o antiX Linux</pt>
@@ -56,6 +58,7 @@ Papirus-Mini antiX
    <ru>Basic set of Papirus icons for antiX Linux</ru>
    <sk>Basic set of Papirus icons for antiX Linux</sk>
    <sl>Osnovni nabor Papirus ikon za antiX Linux</sl>
+   <so>Basic set of Papirus icons for antiX Linux</so>
    <sq>Grup elementar i ikonave Papirus për antiX Linux</sq>
    <sr>Basic set of Papirus icons for antiX Linux</sr>
    <sv>Bas-set av Papirus ikoner för antiX Linux</sv>
